@@ -31,14 +31,14 @@ class SnappyParser(JsonParser):
                 newByte = nowByte ^ int(password & 0xff)
                 xor.extend(bytes([newByte]))
             return xor
-        elif six.PY2:
-            xor = ''.join(chr(ord(x) ^ (password & 0xff)) for (x) in raw_data)
-            return xor
+        # elif six.PY2:
+        #     xor = ''.join(chr(ord(x) ^ (password & 0xff)) for (x) in raw_data)
+        #     return xor
         else:
             self._crypt_data = False
             return raw_data
 
     def get_headers(self):
-        if self._crypt_data:
+        if self._crypt_data and six.PY3:
             return {'content-type': 'application/json', 'X-Compress-Codec': '2', 'X-Crypt-Codec': '1'}
         return {'content-type': 'application/json', 'X-Compress-Codec': '2'}
